/*
 * Segment 2 (KEx),  SWE2.4 Email/Fax/SMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.emailfaxsms;

import java.util.ResourceBundle;
import java.util.logging.Level;

import com.bitctrl.i18n.MessageHandler;

import de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * Versorgt die Applikation mit lokalisierten Benutzernachrichten.
 *
 * @author BitCtrl Systems GmbH, Steffen Gieseler
 */
public enum EmailFaxSmsMsg implements MessageHandler,LogNachricht {

	/**
	 * Parameter: 1) Systemobjekt, 2) Attributgruppe, 3) Fuzzy-Wert, 4)
	 * Fehlermeldung.
	 */
	ErrorBeimSendenFuzzyWert(Debug.ERROR),

	/**
	 * Parameter: 1) Name Modul.
	 */
	WarningWarteSchlangeVoll(Debug.WARNING),

	/**
	 * Parameter: 1) Name Modul, 2) Warngrenze.
	 */
	WarningWarteschlangeFuellgrad(Debug.WARNING),

	/** Parameter: 1) Grund. */
	WarningWarteschlangeAbbruch(Debug.WARNING),

	/** Ohne Paramater. */
	WarningAntwortWartenAbbruch(Debug.WARNING),

	/** Ohne Paramater. */
	WarningThreadUnterbrochen(Debug.WARNING),

	/** Parameter: 1) Grund. */
	WarningLeseFehler(Debug.WARNING),

	/** Parameter: 1) Grund. */
	WarningSchreibFehler(Debug.WARNING),

	/** Parameter: 1) Grund. */
	WarningDatenLesen(Debug.WARNING),

	/** Parameter: 1) Grund. */
	WarningDatenSchreiben(Debug.WARNING),

	/** Ohne Paramater. */
	WarningWartenThreadEndeUnterbrochen(Debug.WARNING),

	/** Ohne Paramater. */
	WarningWartenThreadEnde(Debug.WARNING),

	/** Ohne Paramater. */
	WarningDatenVersandUnterbrochen(Debug.WARNING),

	/** Ohne Paramater. */
	WarningStatusVersand(Debug.WARNING),

	/** Parameter: 1) Typ (Fax/Email/SMS). */
	WarningNochNichtParametriert(Debug.WARNING),

	/** Parameter: 1) Text der Warnung. */
	WarningAllgemein(Debug.WARNING),

	/** Parameter: 1) Grund. */
	InfoVersandUnterbrochen(Debug.INFO),

	/** Parameter: 1) Typ (Fax/Email/SMS). */
	InfoParameterEmpfangen(Debug.INFO),

	/** Parameter: 1) Typ des Auftrags. */
	InfoAuftragEmpfangen(Debug.INFO),

	/** Parameter: 1) Anzahl Systemobjekte. */
	ConfigMesswertEmpfaengerBereit(Debug.CONFIG),

	/** Ohne Paramater. */
	FineAlleThreadsGestartet(Debug.FINE),

	/** Ohne Paramater. */
	FineVerwaltungKomplett(Debug.FINE),

	/** Ohne Paramater. */
	FineParametrierungEmpfangen(Debug.FINE),

	/** Parameter: 1) Application-ID, 2) lfd. Nr, 3) Typ des Auftrags. */
	FineAuftragEingefuegt(Debug.FINE),

	/** Parameter: 1) Name Comm-Port. */
	FineCommThreadsGestartet(Debug.FINE),

	/** Parameter: 1) Name Comm-Port. */
	FineComPortGeoeffnet(Debug.FINE),

	/** Parameter: 1) Name Comm-Port. */
	FineComPortGeschlossen(Debug.FINE),

	/** Parameter: 1) Anzahl. */
	FineModemWriteBytes(Debug.FINE),

	/** Parameter: 1) Anzahl 2) Datei. */
	FineSendeBinaerBytes(Debug.FINE),

	/** Parameter: 1) Thread-Name. */
	FinerThreadBeendet(Debug.FINER),

	/** Parameter: 1) Antwort. */
	FinestModemAntwort(Debug.FINEST),

	/** Parameter: 1) Kommando. */
	FinestModemCommand(Debug.FINEST);

	/** Das Resource-Bundle. */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle
			.getBundle(EmailFaxSmsMsg.class.getCanonicalName());

	/** Die Eigenschaft {@code level}. */
	private final Level level;

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	private EmailFaxSmsMsg(final Level level) {
		this.level = level;
	}

	@Override
	public MessageGrade getBmvLevel() {
		if (level.equals(Debug.WARNING)) {
			return MessageGrade.WARNING;
		} else if (level.equals(Debug.ERROR)) {
			return MessageGrade.ERROR;
		}
		return null;

	}

	@Override
	public Level getLogLevel() {
		return level;
	}

	@Override
	public ResourceBundle getResourceBundle() {
		return EmailFaxSmsMsg.RESOURCE_BUNDLE;
	}

	@Override
	public String toString() {
		return getResourceBundle().getString(name());
	}

}
