/**
 * Copyright (C) 2007 BitCtrl Systems GmbH 
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:<br>
 * BitCtrl Systems GmbH<br>
 * Weißenfelser Straße 67<br>
 * 04229 Leipzig<br>
 * Phone: +49 341-490670<br>
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.emailfaxsms;

import java.io.File;

import org.junit.Test;

import de.bsvrz.kex.emailfaxsms.AsyncSerialPortCommunicator.ModemType;
import de.bsvrz.kex.emailfaxsms.fax.sender.KexFaxSender;

/**
 * Testet den Fax Versand
 * 
 * @author BitCtrl Systems GmbH, Bachraty
 *
 */
public class KexFaxSenderTester extends KexFaxSender {

	/**
	 *  Parameter
	 */
	static final String TEST_FAX_HI = "extra\\fax_hi.g3";
	static final String TEST_FAX_LOW = "extra\\fax_low.g3";
	static final String TEST_EMPFAENGER = "15";
	static final String TEST_COM_PORT = "COM1";
	static final int    TEST_BAUD_RATE = 57600;
	static final String TEST_FAX_INITSEQ = "AT&F&C1&D2&K3S7=90M0";
	
	/**
	 * Konstruktor
	 * 
	 * @param com Com-Port
	 * @param baud Baudrate
	 * @param timeout Timeout in s
	 * @param typ Modem Typ
	 * @param gsmPin Pin Code
	 * @param init Init Sequenz
	 * @param prefix Wahl-Praefix
	 * @throws Exception Wenn kein Zugriff zum COM-Port moeglich ist
	 */
	public KexFaxSenderTester(String com, int baud, long timeout, ModemType typ,
				String gsmPin, String init, String prefix) throws Exception {
			super(com, baud, timeout, typ, gsmPin, init, prefix);
		}
	
	/**
	 *  Standardkonstruktor
	 * @throws Exception
	 */
	public KexFaxSenderTester() throws Exception {
		super(TEST_COM_PORT, TEST_BAUD_RATE, 120, ModemType.MODEM_FESTNETZ, "", TEST_FAX_INITSEQ, "");
	}
	
	/**
	 * Der Test
	 * @throws Exception
	 */
	public void testMain()  throws Exception {
		AsyncSerialPortCommunicator comm = new AsyncSerialPortCommunicator(TEST_COM_PORT, TEST_BAUD_RATE,  100*KILO_BYTE, 100*KILO_BYTE, timeout, true);
		comm.setDebug(true);
		VersandStatus stat = send2(comm, "KEX FAX CLASS 2", TEST_EMPFAENGER, true, new File(TEST_FAX_HI));
		System.err.println("VERSAND STATUS: " + stat.getVersandFehlerMeldung());
		Thread.sleep(3000);
		stat = send20(comm, "KEX FAX CLASS 2.0", TEST_EMPFAENGER, false, new File(TEST_FAX_LOW));
		System.err.println("VERSAND STATUS: " + stat.getVersandFehlerMeldung());
		comm.beenden();
	}
	
	/**
	 * TestMethode
	 */
	@Test 
	public void test() {
		try {
			KexFaxSenderTester sender = new KexFaxSenderTester();
			sender.testMain();
		} catch (Exception e) {
			System.err.print("FEHLER: " + e.getMessage() );
			e.printStackTrace();
		}
	}
}
