/**
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:<br>
 * BitCtrl Systems GmbH<br>
 * Weißenfelser Straße 67<br>
 * 04229 Leipzig<br>
 * Phone: +49 341-490670<br>
 * mailto: info@bitctrl.de
 */
package de.bsvrz.kex.emailfaxsms;

import java.io.File;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.kex.emailfaxsms.AsyncSerialPortCommunicator.ModemType;
import de.bsvrz.kex.emailfaxsms.fax.sender.KexFaxSender;
import de.bsvrz.kex.emailfaxsms.fax.texter.KexFaxTexter;;

/**
 * Testet die Klasse KexFaxTexter
 * 
 * @author BitCtrl Systems GmbH, Bachraty
 *
 */
public class KexFaxTexterTest extends KexFaxTexter {

	/**
	 * Testet den Versand, stat Absenden macht er eine TextAusgabe
	 * 
	 * @author BitCtrl Systems GmbH, Bachraty
	 *
	 */
	protected class KexFaxSenderTest extends KexFaxSender {

		/**
		 * Standardkonstruktor
		 *
		 * @param com
		 *            Com-Port
		 * @param baud
		 *            Baudrate
		 * @param timeout
		 *            Timeout in Sekunden
		 * @param typ
		 *            Modem Typ
		 * @param gsmPin
		 *            Pin Code
		 * @param init
		 *            Init Sequenz
		 * @param prefix
		 *            Wahl-Praefix
		 * @throws Exception
		 *             Wenn kein Zugriff zum COM-Port moeglich ist
		 */
		public KexFaxSenderTest(final String com, final int baud, final long timeout, final ModemType typ,
				final String gsmPin, final String init, final String prefix) throws Exception {
			super(com, baud, timeout, typ, gsmPin, init, prefix);
		}

		@Override
		public VersandStatus send(final String faxKennung, final String Nummer, final boolean hochAufloesend,
				final File rasterGrafik) {
			System.out.println("# FAX # " + " KENNUNG:" + faxKennung + " NR:" + prefix + Nummer + " HOCHAUFL:"
					+ hochAufloesend + " FILE:" + rasterGrafik);

			try {
				Thread.sleep(1500);
			} catch (final Exception e) {
				e.printStackTrace();
			}
			return VersandStatus.VERSAND_OK;
		}
	}

	@Override
	synchronized public void update(final ResultData[] results) {
		super.update(results);

		for (final ResultData resDatei : results) {
			final Data data = resDatei.getData();
			if (data == null) {
				continue;
			}
			if (resDatei.getDataDescription().getAttributeGroup().equals(ddPARAM.getAttributeGroup())) {

				final String com = data.getItem("ModemParameter").getItem("COM-Port").asTextValue().getText();
				final int baud = data.getItem("ModemParameter").getItem("BaudRate").asUnscaledValue().intValue();
				final long timeout = data.getItem("ModemParameter").getItem("EmpfangsTimeout").asUnscaledValue()
						.longValue();

				final int typ = data.getItem("ModemParameter").getItem("ModemTyp").asUnscaledValue().intValue();

				final String gsmPin = data.getItem("ModemParameter").getItem("GsmPin").asTextValue().getText();
				final String init = data.getItem("ModemParameter").getItem("InitialisierungsBefehl").asTextValue()
						.getText();
				final String prefix = data.getItem("ModemParameter").getItem("WahlPraefix").asTextValue().getText();

				stdFaxKennung = data.getItem("FaxKennung").asTextValue().getText();
				final int hochaufloesend = data.getItem("Hochaufloesend").asUnscaledValue().intValue();
				if (hochaufloesend == 1) {
					stdHochaufloesend = true;
				} else {
					stdHochaufloesend = false;
				}

				stdEmpfaenger = data.getItem("StandardEmpfaenger").asTextValue().getText();

				ModemType modemTyp = ModemType.MODEM_FESTNETZ;
				switch (typ) {
				case 0:
					modemTyp = ModemType.MODEM_FESTNETZ;
					break;
				case 1:
					modemTyp = ModemType.MODEM_GSM;
					break;
				case 2:
					modemTyp = ModemType.MODEM_GPRS;
					break;
				}
				try {
					sender = new KexFaxSenderTest(com, baud, timeout, modemTyp, gsmPin, init, prefix);
				} catch (final Exception e) {
					getLogger().warning("Fehler beim Starten von KexFaxSender: " + e.getMessage());
				}
			}
		}
	}
}
