/*
 * Segment 2 (KEx),  SWE2.4 Email/Fax/SMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.emailfaxsms;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.ClientSenderInterface;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.SenderRole;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.bitctrl.daf.LogTools;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Eine Singleton Klasse die f&uuml;r die Versanddaten angemeldent ist.
 *
 * @author BitCtrl Systems GmbH, Bachraty
 */
public class VersandStatusSender implements ClientSenderInterface {

	/**
	 * Singleton Instanz.
	 */
	private static final VersandStatusSender INSTANZ = new VersandStatusSender();

	/**
	 * Ergibt die Instanz des VersandStatusSenders.
	 *
	 * @return Instanz
	 */
	public static VersandStatusSender getInstanz() {
		return VersandStatusSender.INSTANZ;
	}

	/**
	 * Verbindung zum DAV.
	 */
	private ClientDavInterface dav;

	/**
	 * Datenbeschreibung f&uuml;r die Anmeldung als Quelle der Versandmeldungen.
	 */
	private DataDescription ddStatusmeldung;

	/**
	 * Das Versandmodul.
	 */
	private SystemObject modul;

	@Override
	public void dataRequest(final SystemObject object, final DataDescription dataDescription, final byte state) {
		/** */
	}

	/**
	 * Initialisierung.
	 *
	 * @param davconnection
	 *            Verbindung zum DAV
	 * @param versandmodul
	 *            Objekt vom Typ typ.versandModulExterneMeldungen
	 */
	public void init(final ClientDavInterface davconnection, final SystemObject versandmodul) {
		this.dav = davconnection;
		this.modul = versandmodul;

		ddStatusmeldung = new DataDescription(davconnection.getDataModel().getAttributeGroup("atg.versandStatus"),
				davconnection.getDataModel().getAspect("asp.auftragsStatus"));
		try {
			davconnection.subscribeSender(this, versandmodul, ddStatusmeldung, SenderRole.source());
		} catch (final Exception e) {
			Debug.getLogger().warning("Fehler bei Anmeldung als Sender fÜr Statusmeldungen:" + e.getMessage());
		}
	}

	@Override
	public boolean isRequestSupported(final SystemObject object, final DataDescription dataDescription) {
		return false;
	}

	/**
	 * Sendet eine StatusMeldung des Versands zum DAV.
	 *
	 * @param auftrag
	 *            Der zu Auftrag, der versendet werden sollte
	 * @param status
	 *            Status des Versandes
	 */
	public synchronized void send(final IVersandAuftrag auftrag, final VersandStatus status) {
		final Data data = dav.createData(ddStatusmeldung.getAttributeGroup());

		data.getItem("MeldungsID").getItem("ApplikationsID").asUnscaledValue().set(auftrag.getAppID());
		data.getItem("MeldungsID").getItem("LaufendeNummer").asUnscaledValue().set(auftrag.getLaufNr());

		if (status.getVersandErfolg()) {
			data.getItem("VersandOk").asUnscaledValue().set(1);
			data.getItem("Fehlermeldung").asTextValue().setText("Kein Fehler");
		} else {
			data.getItem("VersandOk").asUnscaledValue().set(0);
			data.getItem("Fehlermeldung").asTextValue().setText(status.getVersandFehlerMeldung());
		}

		final ResultData resDatei = new ResultData(modul, ddStatusmeldung, System.currentTimeMillis(), data);
		try {
			dav.sendData(resDatei);
			Debug.getLogger().finest(
					"VERSAND # AppID: " + auftrag.getAppID() + " LaufNr: " + auftrag.getLaufNr() + " " + status);
		} catch (final Exception e) {
			LogTools.log(Debug.getLogger(), EmailFaxSmsMsg.WarningStatusVersand);
		}
	}
}
